> “Imagine your beautiful program locked up in a drawer and never used again. Now imagine it being used effectively and with pleasure by many people. Which dream gives you satisfaction?” - Eric S. Raymond

Contributors to the rdflib-sqlalchemy project:
----------------------------------------------

* Françoise Conil - https://github.com/fconil
* Adam Ever-Hadani - https://github.com/adamhadani
* Yves-Marie Haussonne - https://github.com/ymph 
* Graham Higgins - https://github.com/gjhiggins
* Ryan Shaw - https://github.com/rybesh
* Thibault Clérice - https://github.com/ponteineptique
* Mark Watts - https://github.com/mwatts2015
